---

# monkstools: Advertising Delivery ROI Analysis Framework

`monkstools` is a Python module crafted for a streamlined analysis and visualization of advertising Return on Investment (ROI) across different platforms. This guide offers a concise and clear walkthrough to help you utilize its features effectively.

## **Overview**

- **What is it?**  
  A template Python framework to analyze and visualize the ROI for product advertising across multiple platforms.

- **Who is it for?**  
  Programmers, data analysts, and professionals aiming to evaluate advertising ROI.

- **Usage Context**:  
  While designed for ideation and collaboration, remember that real-world applications would require extensive model training and real data.

## **Getting Started**

### 1. **Installation**

Before using `monkstools`, ensure you have it installed. If not, you can do so using pip:

```bash
pip install monkstools
```

### 2. **Initialize the Framework**

Once installed, initiate the `ROICalculator` to automatically set up both the `ProductPreference` and `TransmissionCost` classes.

```python
from monkstools.roi_calculator import ROICalculator  

preference_file = 'path_to_preference_file.csv'
cost_file = 'path_to_cost_file.csv'
roi_calculator = ROICalculator(preference_file, cost_file)
```

### 3. **Define Products & Platforms**

Specify the products and platforms you wish to analyze:

```python
products = ['Example Product 1', ...]
platforms = ['Example Platform 1', ...]
```

### 4. **Visualize ROI Matrix**

Run the following to compute and showcase the ROI matrix:

```python
ROICalculator.display_roi_matrix(roi_calculator, products, platforms)
```

### 5. **Debugging**

For detailed insights or debugging, enable verbose mode:

```python
# For instance:
roi_calculator.calculate(product_name='Example Product 1', platform_name='Example Platform 1', verbose=True)
```

## **Hands-On Example**

To provide a clearer understanding, here's a complete example using the framework:

```python
import pkg_resources
import matplotlib.pyplot as plt
from monkstools.roi_calculator import ROICalculator  

def test_display_roi_matrix():

    # Specify the paths to your data files
    preference_file = pkg_resources.resource_filename('monkstools', 'd4_data_map_product_costomerType.csv')
    cost_file = pkg_resources.resource_filename('monkstools', 'd3_data_map_delivery_cost_media.csv')
    
    # Initialize the calculator with the provided data
    roi_calculator = ROICalculator(preference_file, cost_file)

    # Define the products and platforms for analysis
    products = [
        'Toyota Corolla', 'Toyota RAV4', 'Toyota Camry', 'Toyota Land Cruiser', 'Toyota Hilux', 
        'Toyota Prius', 'Toyota Tacoma', 'Toyota Highlander', 'Toyota Sienna', 'Toyota 4Runner'
    ]
    platforms = [
        'Youtube', 'Facebook', 'WhatsApp', 'Instagram', 'WeChat', 'TikTok', 'QQ', 'Weibo', 'Twitter', 
        'LinkedIn', 'Snapchat', 'Pinterest', 'Reddit', 'Telegram', 'LINE', 'Viber', 'IMO', 'Zalo', 'VK', 'Odnoklassniki'
    ]

    # Display the ROI matrix
    roi_calculator.display_roi_matrix(products, platforms) 

    # Post-execution: Verify the chart manually or check the "ROI_Comparison.png" file
    # Optionally, automate assertions based on expected outcomes

if __name__ == "__main__":
    test_display_roi_matrix()
    print("Test executed. Please verify the output chart.")
```

Run the above script to visualize the ROI across various platforms for the specified products. Ensure you adjust the paths to your data files accordingly.

---

*Documentation updated and compiled based on the original work by Xiaowen Kang, 2023.8.24.*



### README.md

---

# monkstools: Advertising Delivery ROI Analysis Framework

`monkstools` is a Python module designed to analyze and visualize the Return on Investment (ROI) of product advertising across different platforms. It provides insights into which platform might yield the highest returns for advertising a particular product. While this framework is provided for demonstration purposes, the actual results in a production setting would be based on in-depth model training and real-world data.

## Overview

The primary goal of `monkstools` is to serve as a platform for programmers and data analysts to discuss, share, and collaborate on analyzing the ROI of advertising delivery. It's a template to kick-start discussions and exchange ideas on the intricacies of advertising dynamics across different platforms for various products.

## Key Components

**1. ProductPreference Class**
- **Purpose**: Retrieve product preference values for specified products and customer types.
- **Primary Method**: `get_preference(product_name, customer_type, verbose=False)`

**2. TransmissionCost Class**
- **Purpose**: Fetch transmission cost values for designated platforms and customer types.
- **Primary Method**: `get_cost(platform_name, customer_type, verbose=False)`

**3. ROICalculator Class**
- **Purpose**: Compute and visualize ROIs.
- **Primary Methods**:
  - `calculate(product_name, platform_name, verbose=False)`: Computes the ROI for a given product and platform.
  - `display_roi_matrix(roi_calculator, products, platforms)`: Visualizes the ROI matrix.

## Usage Guide

**1. Initialization**

   First, you need to initialize the `ROICalculator` object, which, in turn, initializes the `ProductPreference` and `TransmissionCost` objects.
   
   ```python
   preference_file = 'path_to_preference_file.csv'
   cost_file = 'path_to_cost_file.csv'
   roi_calculator = ROICalculator(preference_file, cost_file)
   ```

**2. Setting Up Products and Platforms**

   Define the list of products and platforms you're interested in analyzing.

   ```python
   products = ['Example Product 1', ...]  
   platforms = ['Example Platform 1', ...] 
   ```

**3. Displaying the ROI Matrix**

   Use the `display_roi_matrix` method of the `ROICalculator` class to compute and showcase the ROI matrix.

   ```python
   ROICalculator.display_roi_matrix(roi_calculator, products, platforms)
   ```

**4. Debugging and Logging**

   Set `verbose=True` when calling methods to print additional debugging and logging information.

## Note

This framework is intended for team discussions and sharing. The specific functions and data here are examples, and in a real-world scenario, deeper model training would be necessary. The final outcome is contingent on actual data and post-deep-training results. This is merely a conceptual framework and thought process to facilitate programmers' exchange of ideas.

---

To leverage this library, ensure `monkstools` is installed and data provided matches expected formats.

import pkg_resources
import matplotlib.pyplot as plt

from monkstools.roi_calculator import ROICalculator  

def test_display_roi_matrix():

    preference_file = pkg_resources.resource_filename('monkstools', 'd4_data_map_product_costomerType.csv')
    cost_file = pkg_resources.resource_filename('monkstools', 'd3_data_map_delivery_cost_media.csv')
    
    roi_calculator = ROICalculator(preference_file, cost_file)

    products = ['Toyota Corolla', 'Toyota RAV4', 'Toyota Camry', 'Toyota Land Cruiser', 'Toyota Hilux', 
                'Toyota Prius', 'Toyota Tacoma', 'Toyota Highlander', 'Toyota Sienna', 'Toyota 4Runner']
    
    platforms = ['Youtube', 'Facebook', 'WhatsApp', 'Instagram', 'WeChat', 'TikTok', 'QQ', 'Weibo', 'Twitter', 
                 'LinkedIn', 'Snapchat', 'Pinterest', 'Reddit', 'Telegram', 'LINE', 'Viber', 'IMO', 'Zalo', 'VK', 'Odnoklassniki']

    roi_calculator.display_roi_matrix(products, platforms) 

    # Verify manually by checking the displayed chart or saved "ROI_Comparison.png"
    # Optionally, you could also add some automated assertions here based on expected values or behaviors

if __name__ == "__main__":
    test_display_roi_matrix()
    print("Test executed. Please verify the output chart.")


---

xiaowen kang. 2023.8.24